@@ -284,21 +284,47 @@ ifile_bitify_document(htable * message)
  * the information to the given file */
 /* Written by Jason Rennie <jrennie@ai.mit.edu> for ifile */
 void 
-ifile_print_ratings (FILE * FP, category_rating * ratings, ifile_db * idata)
+ifile_print_ratings (FILE * FP, category_rating * ratings, ifile_db * idata,
+		     int thresh)
 {
   long int i;
 
   for (i = 0; i < idata->num_folders; i++)
     fprintf(FP, "%s %.8f\n", ratings[i].category, ratings[i].rating);
+  
+  if (thresh != 0 &&
+      idata->num_folders > 0 && 
+      (ratings[0].rating + ratings[1].rating) != 0)
+  {
+    fprintf(FP, "diff[%s,%s](%%) %.2f\n", 
+                ratings[0].category, ratings[1].category,
+                -(ratings[0].rating - ratings[1].rating) / 
+                  (ratings[0].rating + ratings[1].rating) * 100);
+  }
   fprintf(FP, "---------\n");
 }
 
 /* Written by Karl Vogel <vogelke@dnaco.net> for ifile */
 void
 ifile_concise_ratings (char * path, FILE * FP, category_rating * ratings,
-                     ifile_db * idata)
+                     ifile_db * idata, int thresh)
 {
-    if (path) fprintf (FP, "%s ", path);
+  //if (path) fprintf (FP, "%s ", path);
+  float diff=0;
+  
+  diff=thresh+1;
+
+  if (thresh != 0 &&
+      idata->num_folders > 0 && 
+      (ratings[0].rating + ratings[1].rating) != 0)
+  {
+    diff = -(ratings[0].rating - ratings[1].rating) / 
+                  (ratings[0].rating + ratings[1].rating) * 1000;
+  }
+  if (path) fprintf (FP, "%s ", path);
+  if (idata->num_folders > 0 && diff < thresh) 
+    fprintf (FP, "%s,%s\n", ratings[0].category, ratings[1].category);
+  else
     fprintf (FP, "%s\n", ratings[0].category);
 }
 
